<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Edit Form Modtagere");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Edit Form Modtagere");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Form Side");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Du kan indstille mere end én modtager ved at adskille e-mails med komma.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Gemmer modtager ...");
define('VIEW_FORM_TABLES_HEADING', "Se formularer");
define('VIEW_FORM_TABLES_BTN', "Se formularer");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Vælg en tabel til visning");
define('VIEW_FORM_TABLES_FILTER_READ', "Filter Læs meddelelser");
?>